/*
 * Copyright 2010-13 Fraunhofer ISE
 *
 * This file is part of j62056.
 * For more information visit http://www.openmuc.org
 *
 * j62056 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * j62056 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with j62056.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

import java.io.IOException;
import java.util.List;

import org.openmuc.j62056.Connection;
import org.openmuc.j62056.DataSet;

public class ReadMeter {

	public static void main(String[] args) {
		if (args.length < 1 || args.length > 3) {
			System.out.println("Usage: ReadMeter [-e] [-n] <serialPort>");
			System.out.println("Examples for <serialPort> are /dev/ttyS0 (Linux) or COM1 (Windows)");
			System.out.println("-e = enable handling of echos caused by optical tranceivers");
			System.out.println("-n = disable changing the baud rate from 300 to a faster one during message exchange");
			System.exit(1);
		}

		String serialPortName = "";
		boolean echoHandling = false;
		boolean noBaudRateChange = false;

		for (String arg : args) {
			if (arg.equals("-e")) {
				echoHandling = true;
			}
			else if (arg.equals("-n")) {
				noBaudRateChange = true;
			}
			else {
				serialPortName = arg;
			}
		}

		Connection connection = new Connection(serialPortName, echoHandling, noBaudRateChange);

		try {
			connection.open();
		} catch (IOException e) {
			System.err.println("Failed to open serial port: " + e.getMessage());
			System.exit(1);
		}

		List<DataSet> dataSets = null;
		try {
			dataSets = connection.read(30000);
		} catch (IOException e) {
			connection.close();
			System.err.println("IOException while trying to read: " + e.getMessage());
			System.exit(1);
		}

		if (dataSets == null) {
			System.err.print("Read attempt timed out");
			connection.close();
			System.exit(1);
		}

		System.out.println("Got the following data sets:");
		for (DataSet dataSet : dataSets) {
			System.out.println("id=" + dataSet.getId() + " value=" + dataSet.getValue() + " unit=" + dataSet.getUnit());
		}

		System.out.println("Reading meter successfully finished.");
		connection.close();

	}

}
